
.. _algorithms/shortestpaths:

.. py:module:: jgrapht.algorithms.shortestpaths

Shortest Paths
**************

Algorithms
----------


All classic algorithms for shortest paths are provided. See below for details.

.. automodule:: jgrapht.algorithms.shortestpaths
   :members:
   :noindex:

Types
-----

The shortest path module contains the following classes for the 
representation of the shortest path queries. All methods related to shortest paths
return instances from these classes.

.. autoclass:: jgrapht.types.GraphPath
   :members:

.. autoclass:: jgrapht.types.SingleSourcePaths
   :members:

.. autoclass:: jgrapht.types.AllPairsPaths
   :members:

.. autoclass:: jgrapht.types.MultiObjectiveSingleSourcePaths
   :members:

